/*********************************************************
This is a library for the MPR121 12-channel Capacitive touch sensor

Designed specifically to work with the MPR121 Breakout in the Adafruit shop 
  ----> https://www.adafruit.com/products/

These sensors use I2C communicate, at least 2 pins are required 
to interface

Adafruit invests time and resources providing this open source code, 
please support Adafruit and open-source hardware by purchasing 
products from Adafruit!

Written by Limor Fried/Ladyada for Adafruit Industries.  
BSD license, all text above must be included in any redistribution
**********************************************************/

#include <Wire.h>
#include "Adafruit_MPR121.h"
#include <SoftwareSerial.h>// import the serial library

// You can have up to 4 on one i2c bus but one is enough for testing!
Adafruit_MPR121 cap = Adafruit_MPR121();

SoftwareSerial Genotronex(10, 11); // RX, TX

// Keeps track of the last pins touched
// so we know when buttons are 'released'
uint16_t lasttouched = 0;
uint16_t currtouched = 0;
int nSensorsNeeded = 0; // number of sensors that need to be touched for LED to light
int nSensorsActive = 0;
int sensorList[10] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0}; // sensor array marking which sensors are touched and which are not
int ledPin = 13; // choose the pin for the LED
int val = 0;     // variable for reading the pin status
int nPeople;
int BluetoothData;

void setup() {
  Genotronex.begin(9600);

  while (!Serial) { // needed to keep leonardo/micro from starting too fast!
    delay(5);
  }
  
  Genotronex.println("Touch sensor test"); 
  Genotronex.println("Bluetooth On please wait....");
  
  // Default address is 0x5A, if tied to 3.3V its 0x5B
  // If tied to SDA its 0x5C and if SCL then 0x5D
  if (!cap.begin(0x5A)) {
    Genotronex.println("MPR121 not found, check wiring?");
    while (1);
  }
  Genotronex.println("MPR121 found!");


  Genotronex.println("Enter number of people: \n");
  while (Genotronex.available() == 0);
  nPeople = Genotronex.parseInt(); //read int or parseFloat for ..float...
  Genotronex.print("Number of people: "); Genotronex.println(nPeople);

  nSensorsNeeded = nPeople*2; // define number of sensors needed to be touched based on input of how many people entered the room
  pinMode(ledPin, OUTPUT);  // declare LED as output
  
}

void loop() {
  //waiting for input
  if (Genotronex.available() > 0){
    BluetoothData=Genotronex.read();
    nPeople = BluetoothData - '0';
    Genotronex.println("");
    Genotronex.print("Number of people: "); Genotronex.println(nPeople);
  }

  nSensorsNeeded = nPeople*2; // define number of sensors needed to be touched based on input of how many people entered the room
  
  // Get the currently touched pads
  currtouched = cap.touched();
   
  for (uint8_t i=0; i<10; i++) {
    // if it *is* touched and *wasnt* touched before, alert! and set array value of pin to 1
    if ((currtouched & _BV(i)) && !(lasttouched & _BV(i)) ) {
      Genotronex.print(i); Genotronex.println(" touched");
      sensorList[i] = 1;
    }
    // if it *was* touched and now *isnt*, alert! and set array value of pin to 0
    if (!(currtouched & _BV(i)) && (lasttouched & _BV(i)) ) {
      Genotronex.print(i); Genotronex.println(" released");
      sensorList[i] = 0;
    }
  }
  int oldnSensorActive = nSensorsActive;
  // check array sum

  for (int j=0; j < 10; ++j) {
    //Serial.print(sensorList[j]);
    //Serial.print(", ");
    nSensorsActive += sensorList[j];
  }
  nSensorsActive = nSensorsActive - oldnSensorActive;
  
  Genotronex.println("");
  Genotronex.print("Number of sensors touched: ");Genotronex.println(nSensorsActive);
  delay(100);

  // if array sum == nSensors, light LED
  if (nSensorsActive == nSensorsNeeded) {
    digitalWrite(ledPin, HIGH);  // turn LED ON
  } else {
    digitalWrite(ledPin, LOW);  // turn LED OFF
  }

  
  // reset our state
  lasttouched = currtouched;

  // comment out this line for detailed data from the sensor!
  return;
  
}
